==> mobilenetv2_mmcv-v2.2.zip: mobilenetv2_mmcv-v2.2/README.md <==
# Mobilenetv2

## 论文

MobileNetV2: Inverted Residuals and Linear Bottlenecks

- https://openaccess.thecvf.com/content_cvpr_2018/papers/Sandler_MobileNetV2_Inverted_Residuals_CVPR_2018_paper.pdf

## 模型结构

MobileNetV2是一种轻量级的卷积神经网络模型，由Google在2018年提出。它是MobileNet系列中的第二个版本，主要用于移动设备和嵌入式设备等资源受限的环境中进行图像分类、目标检测等计算机视觉任务。

![loading-ag-535](./images/d15a0e56517b4f7284a862f1d6eaef9a.png)



## 算法原理

MobileNetV2的网络结构主要由两部分组成：特征提取层和分类器。

![20231124104337](./images/20231124104337.png)

## 环境配置

### Docker（方法一）

推荐使用docker方式运行，拉取提供的docker镜像

```shell
docker pull image.sourcefind.cn:5000/dcu/admin/base/pytorch:2.1.0-ubuntu20.04-dtk24.04.1-py3.10
```

基于拉取的镜像创建容器

```shell
# <your IMAGE ID or NAME>用以上拉取的docker的镜像ID或名称替换
docker run -it --name=mobilenetv2 --network=host --ipc=host --shm-size=16g  --device=/dev/kfd --device=/dev/dri --device=/dev/mkfd --group-add video --privileged --cap-add=SYS_PTRACE --security-opt seccomp=unconfined -v /opt/hyhal:/opt/hyhal:ro -v $PWD/mobilenetv2_mmcv:/home/mobilenetv2_mmcv <your IMAGE ID> bash
```

克隆并安装git仓库，安装相关依赖

```python
git clone --recursive http://developer.hpccube.com/codes/modelzoo/mobilenetv2_mmcv.git
cd mobilenetv2_mmcv/mmpretrain-mmcv
pip install -e .
pip install -r requirements.txt
```

### Dockerfile（方法二）

```shell
cd mobilenetv2_mmcv/docker
docker build --no-cache -t mobilenetv2_mmcv:latest .
docker run -it --name=mobilenetv2 --network=host --ipc=host --shm-size=16g  --device=/dev/kfd --device=/dev/dri --device=/dev/mkfd --group-add video --privileged --cap-add=SYS_PTRACE --security-opt seccomp=unconfined -v /opt/hyhal:/opt/hyhal:ro -v $PWD/mobilenetv2_mmcv:/home/mobilenetv2_mmcv <your IMAGE ID> bash
pip install -e .
# 若遇到Dockerfile启动的方式安装环境需要长时间等待，可注释掉里面的pip安装，启动容器后再安装python库：
pip install -r requirements.txt
```

### Anaconda（方法三）

1、关于本项目DCU显卡所需的特殊深度学习库可从光合开发者社区下载安装： https://developer.hpccube.com/tool/

```plaintext
DTK驱动: DTK-24.04.1
python==3.10
torch==2.1.0
torchvision==0.16.0+das1.1.git7d45932.abi1.dtk2404.torch2.1
mmcv==2.0.1+das1.1.gite58da25.abi1.dtk2404.torch2.1.0
Tips：以上dtk驱动、python、torch等DCU相关工具版本需要严格一一对应
```

2、安装mmpretrain仓库源码

```shell
cd mobilenetv2_mmcv/mmpretrain-mmcv
pip install -e .
```

3、其它非特殊库参照requirements.txt安装

```shell
pip install -r requirements.txt
```

## 数据集

### ImageNet

在本项目中可以使用ImageNet数据集。下载ImageNet数据集：https://image-net.org/

可于SCNet快速下载[imagenet-2012](http://113.200.138.88:18080/aidatasets/project-dependency/imagenet-2012)

下载其中的ILSVRC2012_img_train.tar和ILSVRC2012_img_val.tar并按照以下方式解包

```bash
cd mmpretrain-mmcv/data/imagenet
mkdir train && cd train
tar -xvf ILSVRC2012_img_train.tar
```

解包后是1000个tar文件，每个tar对应了一个类别，解包至对应文件夹

```bash
for tarfile in *.tar; do
    dirname="${tarfile%.tar}"
    mkdir "$dirname"
    tar -xvf "$tarfile" -C "$dirname"
done
```

目录结构如下

```
data
└── imagenet
    ├── train
    │   ├── n01440764
    │   │   ├── n01440764_10026.JPEG
    │   │   ├── n01440764_10027.JPEG
    ├──val
    │   ├── n01440764 
    │   │   ├── ILSVRC2012_val_00000293.JPEG
```



### tiny-imagenet-200

由于ImageNet完整数据集较大，可以使用[tiny-imagenet-200](http://cs231n.stanford.edu/tiny-imagenet-200.zip)进行测试  
可于SCNet快速下载[tiny-imagenet-200-scnet](http://113.200.138.88:18080/aidatasets/project-dependency/tiny-imagenet-200)  
此时需要对配置脚本进行一些修改：

- dataset配置文件(configs/\_\_base\_\_/datasets/xxx.py)中，需要对以下字段进行修改
  
  ```python
  # dataset settings
  dataset_type = 'CustomDataset'  # 修改为CustomDataset
  data_preprocessor = dict(
      num_classes=200,  # 修改类别为200
      ...
  )
  ...
  train_dataloader = dict(
      batch_size=32,
      num_workers=5,
      dataset=dict(
          type=dataset_type,
          data_root='data/imagenet',
          data_prefix='train',  # 改为data_prefix='train'，val_dataloader中同理
          pipeline=train_pipeline),
      sampler=dict(type='DefaultSampler', shuffle=True),
  )
  ```

- model配置文件(configs/\_\_base\_\_/models/xxx.py)中，同样需要将类别相关的值设置为200。
  
  ```python
  # model settings
  model = dict(
      type='ImageClassifier',
      ...
      head=dict(
          type='LinearClsHead',
          num_classes=200,  # 将类别数改为200
          ...
      ))
  ```

mmpretrain-mmcv中提供了使用tiny-imagenet-200进行训练的若干配置脚本，可参考进行设置。

## 训练

将训练数据集解压后放置于mmpretrain-mmcv/data/，对于tiny-imagenet，目录结构如下：

```
data
└── imagenet
    ├── test/
    ├── train/
    ├── val/
    ├── wnids.txt
    └── words.txt

```

### 单机8卡训练

tiny-imagenet-200

```shell
bash tools/dist_train.sh mobilenet-v2-test.py 8
```

imagenet

```shell
bash tools/dist_train.sh configs/mobilenet_v2/mobilenet-v2_8xb32_in1k.py 8
```

如需其他卡数训练，将命令中的8改为所需卡数即可

如遇端口占用问题，可在tools/dist_train.sh修改端口

## 应用场景

### 算法类别

图像分类

### 热点行业

制造,能源,交通,网安,安防

## 源码仓库及问题反馈

https://developer.hpccube.com/codes/modelzoo/mobilenetv2_mmcv

## 参考资料

https://github.com/open-mmlab/mmpretrain

==> mobilenetv2_mmcv-v2.5.zip: mobilenetv2_mmcv-v2.5/README.md <==
# MobileNetV2

## 论文

MobileNetV2: Inverted Residuals and Linear Bottlenecks

- https://openaccess.thecvf.com/content_cvpr_2018/papers/Sandler_MobileNetV2_Inverted_Residuals_CVPR_2018_paper.pdf

## 模型结构

MobileNetV2是一种轻量级的卷积神经网络模型，由Google在2018年提出。它是MobileNet系列中的第二个版本，主要用于移动设备和嵌入式设备等资源受限的环境中进行图像分类、目标检测等计算机视觉任务。

![loading-ag-535](./images/d15a0e56517b4f7284a862f1d6eaef9a.png)



## 算法原理

MobileNetV2的网络结构主要由两部分组成：特征提取层和分类器。

![20231124104337](./images/20231124104337.png)

## 环境配置

### Docker（方法一）

推荐使用docker方式运行，拉取提供的docker镜像

```shell
docker pull image.sourcefind.cn:5000/dcu/admin/base/pytorch:2.1.0-ubuntu20.04-dtk24.04.1-py3.10
```

基于拉取的镜像创建容器

```shell
# <your IMAGE ID or NAME>用以上拉取的docker的镜像ID或名称替换
docker run -it --name=mobilenetv2 --network=host --ipc=host --shm-size=16g  --device=/dev/kfd --device=/dev/dri --device=/dev/mkfd --group-add video --privileged --cap-add=SYS_PTRACE --security-opt seccomp=unconfined -v /opt/hyhal:/opt/hyhal:ro -v $PWD/mobilenetv2_mmcv:/home/mobilenetv2_mmcv <your IMAGE ID> bash
```

克隆并安装git仓库，安装相关依赖

```python
git clone --recursive http://developer.hpccube.com/codes/modelzoo/mobilenetv2_mmcv.git
cd mobilenetv2_mmcv/mmpretrain-mmcv
pip install -e .
pip install -r requirements.txt
```

### Dockerfile（方法二）

```shell
cd mobilenetv2_mmcv/docker
docker build --no-cache -t mobilenetv2_mmcv:latest .
docker run -it --name=mobilenetv2 --network=host --ipc=host --shm-size=16g  --device=/dev/kfd --device=/dev/dri --device=/dev/mkfd --group-add video --privileged --cap-add=SYS_PTRACE --security-opt seccomp=unconfined -v /opt/hyhal:/opt/hyhal:ro -v $PWD/mobilenetv2_mmcv:/home/mobilenetv2_mmcv <your IMAGE ID> bash
pip install -e .
# 若遇到Dockerfile启动的方式安装环境需要长时间等待，可注释掉里面的pip安装，启动容器后再安装python库：
pip install -r requirements.txt
```

### Anaconda（方法三）

1、关于本项目DCU显卡所需的特殊深度学习库可从光合开发者社区下载安装： https://developer.hpccube.com/tool/

```plaintext
DTK驱动: DTK-24.04.1
python==3.10
torch==2.1.0
torchvision==0.16.0+das1.1.git7d45932.abi1.dtk2404.torch2.1
mmcv==2.0.1+das1.1.gite58da25.abi1.dtk2404.torch2.1.0
Tips：以上dtk驱动、python、torch等DCU相关工具版本需要严格一一对应
```

2、安装mmpretrain仓库源码

```shell
cd mobilenetv2_mmcv/mmpretrain-mmcv
pip install -e .
```

3、其它非特殊库参照requirements.txt安装

```shell
pip install -r requirements.txt
```

## 数据集

### ImageNet

在本项目中可以使用ImageNet数据集。下载ImageNet数据集：https://image-net.org/

可于SCNet快速下载[imagenet-2012](http://113.200.138.88:18080/aidatasets/project-dependency/imagenet-2012)

下载其中的ILSVRC2012_img_train.tar和ILSVRC2012_img_val.tar并按照以下方式解包

```bash
cd mmpretrain-mmcv/data/imagenet
mkdir train && cd train
tar -xvf ILSVRC2012_img_train.tar
```

解包后是1000个tar文件，每个tar对应了一个类别，解包至对应文件夹

```bash
for tarfile in *.tar; do
    dirname="${tarfile%.tar}"
    mkdir "$dirname"
    tar -xvf "$tarfile" -C "$dirname"
done
```

目录结构如下

```
data
└── imagenet
    ├── train
    │   ├── n01440764
    │   │   ├── n01440764_10026.JPEG
    │   │   ├── n01440764_10027.JPEG
    ├──val
    │   ├── n01440764 
    │   │   ├── ILSVRC2012_val_00000293.JPEG
```



### Tiny-ImageNet-200

由于ImageNet完整数据集较大，可以使用[tiny-imagenet-200](http://cs231n.stanford.edu/tiny-imagenet-200.zip)进行测试，可于SCNet快速下载[tiny-imagenet-200-scnet](http://113.200.138.88:18080/aidatasets/project-dependency/tiny-imagenet-200) ，此时需要对配置脚本进行一些修改，可参照mmpretrain-mmcv子仓库进行配置，其中提供了使用Tiny-ImageNet-200进行训练的若干配置脚本。

将训练数据集解压后放置于mmpretrain-mmcv/data/，对于Tiny-ImageNet，目录结构如下：

```
data
└── imagenet
    ├── test/
    ├── train/
    ├── val/
    ├── wnids.txt
    └── words.txt
```

## 训练

Tiny-ImageNet-200

```shell
bash tools/dist_train.sh mobilenet-v2-test.py 8
```

ImageNet

```shell
bash tools/dist_train.sh configs/mobilenet_v2/mobilenet-v2_8xb32_in1k.py 8
```

tips：如需其他卡数训练，将命令中的8改为所需卡数即可；如遇端口占用问题，可在tools/dist_train.sh修改端口。

## Result

![img](https://developer.hpccube.com/codes/modelzoo/vit_pytorch/-/raw/master/image/README/1695381570003.png)

### 精度

测试数据使用的是ImageNet数据集，使用的加速卡是DCU Z100L。

| 卡数  | 精度                        |
|:---:|:-------------------------:|
| 8   | top1:0.71764;top5:0.90386 |

## 应用场景

### 算法类别

图像分类

### 热点行业

制造,能源,交通,网安,安防

## 源码仓库及问题反馈

https://developer.hpccube.com/codes/modelzoo/mobilenetv2_mmcv

## 参考资料

https://github.com/open-mmlab/mmpretrain
